pysmme
===============
Soft maximin estimation in Python, see Lund, A., S. W. Mogensen and N. R. Hansen (2022). Soft Maximin Estimation for
Heterogeneous Data. Scandinavian Journal of Statistics. url = https://doi.org/10.1111/sjos.12580

Installing
============

.. code-block:: bash

    pip install pysmme

Usage
=====

.. code-block:: bash

    >>> from pysmme.tools import softmaximin
    >>> softmaximin(y, x, zeta,...)